@@ -132,7 +132,7 @@ class FbCheckerJob : public KJob
 {
     Q_OBJECT
 public:
-    explicit FbCheckerJob(const QList<QUrl> &urlsToCheck, QObject *parent = Q_NULLPTR);
+    explicit FbCheckerJob(const QList<QUrl> &urlsToCheck, QObject *parent = nullptr);
     void start() Q_DECL_OVERRIDE;
 
     QUrl validUrl() const;
